==> TeamSportScores-1.1.8.zip: TeamSportScores/action.default.php <==
<?php
# Team Sport Scores. A module for CMS - CMS Made Simple
# Copyright (c) 2008 by Duketown
#
# This function will handle the front end request to Team Sport Scores
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/teamsportscores
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

$gCms = cmsms(); if( !is_object($gCms) ) exit;

if (isset($params['display'])) {
	$display = $params['display'];
}
else {
	$display = 'scores';
}

switch($display) {
	#case 'member':
 	#	break;
	case 'scores':
 		break;
	case 'team':
 		break;
	default:
 		echo $this->Lang('unknown_display', $display);
 		return;
  }

require(dirname(__FILE__).'/function.display'.$display.'.php');

?>

==> TeamSportScores-1.2.0.zip: TeamSportScores/action.default.php <==
<?php
# Team Sport Scores. A module for CMS - CMS Made Simple
# Copyright (c) 2008 by Duketown
#
# This function will handle the front end request to Team Sport Scores
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/teamsportscores
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

$gCms = cmsms(); if( !is_object($gCms) ) exit;

if (isset($params['display'])) {
	$display = $params['display'];
}
else {
	$display = 'scores';
}

$TeamSportScoreversion = $this->GetPreference('TeamSportScoreversion');

switch($display) {
	#case 'member':
 	#	break;
	case 'clubscores';
		$fn = cms_join_path(dirname(__FILE__),'silver','silver.clubscores.php');
		if (!file_exists($fn)) {
			echo $this->Lang('unknown_display', $display);
			return;
		}
 		break;
	case 'member':
		$fn = cms_join_path(dirname(__FILE__),'silver','silver.displaymember.php');
		if (!file_exists($fn)) {
			echo $this->Lang('unknown_display', $display);
			return;
		}
 		break;
	case 'scores':
 		break;
 	case 'standings';
		$fn = cms_join_path(dirname(__FILE__),'silver','silver.standings.php');
		if (!file_exists($fn)) {
			echo $this->Lang('unknown_display', $display);
			return;
		}
 		break;
	case 'team':
 		break;
	default:
		echo $this->Lang('unknown_display', $display);
		return;
}

require(dirname(__FILE__).'/function.display'.$display.'.php');

?>
